
# Class: ProvenanceInfo

Provenance information for an object

URI: [gocam:ProvenanceInfo](https://w3id.org/gocam/ProvenanceInfo)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Activity]++-%20provenances%200..*>[ProvenanceInfo&#124;contributor:string%20*;created:string%20%3F;date:string%20%3F;provided_by:string%20*],[Association]++-%20provenances%200..*>[ProvenanceInfo],[EvidenceItem]++-%20provenances%200..*>[ProvenanceInfo],[Model]++-%20provenances%200..*>[ProvenanceInfo],[Model],[EvidenceItem],[Association],[Activity])](https://yuml.me/diagram/nofunky;dir:TB/class/[Activity]++-%20provenances%200..*>[ProvenanceInfo&#124;contributor:string%20*;created:string%20%3F;date:string%20%3F;provided_by:string%20*],[Association]++-%20provenances%200..*>[ProvenanceInfo],[EvidenceItem]++-%20provenances%200..*>[ProvenanceInfo],[Model]++-%20provenances%200..*>[ProvenanceInfo],[Model],[EvidenceItem],[Association],[Activity])

## Referenced by Class

 *  **None** *[➞provenances](activity__provenances.md)*  <sub>0..\*</sub>  **[ProvenanceInfo](ProvenanceInfo.md)**
 *  **None** *[➞provenances](association__provenances.md)*  <sub>0..\*</sub>  **[ProvenanceInfo](ProvenanceInfo.md)**
 *  **None** *[➞provenances](evidenceItem__provenances.md)*  <sub>0..\*</sub>  **[ProvenanceInfo](ProvenanceInfo.md)**
 *  **None** *[➞provenances](model__provenances.md)*  <sub>0..\*</sub>  **[ProvenanceInfo](ProvenanceInfo.md)**
 *  **None** *[provenances](provenances.md)*  <sub>0..\*</sub>  **[ProvenanceInfo](ProvenanceInfo.md)**

## Attributes


### Own

 * [➞contributor](provenanceInfo__contributor.md)  <sub>0..\*</sub>
     * Range: [String](types/String.md)
 * [➞created](provenanceInfo__created.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
 * [➞date](provenanceInfo__date.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
 * [➞provided_by](provenanceInfo__provided_by.md)  <sub>0..\*</sub>
     * Range: [String](types/String.md)
